Function ss_ewasm_api::abort [−][src]
pub fn abort() -> !Expand description
Halts execution, reverts all changes to the state and consumes all gas.
pub fn abort() -> !Halts execution, reverts all changes to the state and consumes all gas.