Function ss_ewasm_api::block_coinbase [−][src]
pub fn block_coinbase() -> AddressExpand description
Returns the beneficiary address for the block this transaction is in (current block)
pub fn block_coinbase() -> AddressReturns the beneficiary address for the block this transaction is in (current block)