Function ss_ewasm_api::block_gas_limit [−][src]
pub fn block_gas_limit() -> u64Expand description
Returns the gas limit of the most recent block.
pub fn block_gas_limit() -> u64Returns the gas limit of the most recent block.