Function ss_ewasm_api::calldata_copy [−][src]
Returns the segment of call data beginning at from, and continuing for length bytes.
Returns the segment of call data beginning at from, and continuing for length bytes.