Function ss_ewasm_api::callvalue [−][src]
pub fn callvalue() -> EtherValueExpand description
Returns the value sent with the currently executing call.
pub fn callvalue() -> EtherValueReturns the value sent with the currently executing call.