Function ss_ewasm_api::code_copy [−][src]
Copies the segment of running code beginning at from and continuing for length bytes.
Copies the segment of running code beginning at from and continuing for length bytes.