Function ss_ewasm_api::returndata_copy [−][src]
Returns the segment of return buffer data beginning at from and continuing for length bytes.
Returns the segment of return buffer data beginning at from and continuing for length bytes.